# frozen_string_literal: true

module MMMD
  module Renderers
    # HTML Renderer
    class HTML
      ELEMENT_MAP = {
        "RBMark::DOM::InlinePre" => {
          tag: "code",
          inline: true
        },
        "RBMark::DOM::InlineBreak" => {
          tag: "br",
          inline: true
        },
        "RBMark::DOM::InlineBold" => {
          tag: "strong",
          inline: true
        },
        "RBMark::DOM::InlineItalics" => {
          tag: "em",
          inline: true
        },
        "RBMark::DOM::InlineUnder" => {
          tag: "span",
          inline: true,
          style: "text-decoration: underline;"
        },
        "RBMark::DOM::InlineStrike" => {
          tag: "s",
          inline: true
        },
        "RBMark::DOM::InlineLink" => {
          tag: "link",
          href: true,
          inline: true
        },
        "RBMark::DOM::InlineImage" => {
          tag: "img",
          src: true,
          inline: true
        },
        "RBMark::DOM::ULBlock" => {
          tag: "ul"
        },
        "RBMark::DOM::OLBlock" => {
          tag: "ol"
        },
        "RBMark::DOM::IndentBlock" => {
          tag: "pre"
        },
        "RBMark::DOM::ListElement" => {
          tag: "li"
        },
        "RBMark::DOM::Paragraph" => {
          tag: "p"
        },
        "RBMark::DOM::Heading1" => {
          tag: "h1"
        },
        "RBMark::DOM::Heading2" => {
          tag: "h2"
        },
        "RBMark::DOM::Heading3" => {
          tag: "h3"
        },
        "RBMark::DOM::Heading4" => {
          tag: "h4"
        },
        "RBMark::DOM::Heading5" => {
          tag: "h5"
        },
        "RBMark::DOM::Heading6" => {
          tag: "h6"
        },
        "RBMark::DOM::Document" => {
          tag: "main"
        },
        "RBMark::DOM::CodeBlock" => {
          tag: "pre",
          outer: {
            tag: "code"
          }
        },
        "RBMark::DOM::QuoteBlock" => {
          tag: "blockquote"
        },
        "RBMark::DOM::HorizontalRule" => {
          tag: "hr"
        },
        "RBMark::DOM::Text" => nil
      }.freeze

      def initialize(dom, options)
        @document = dom
        @options = options
      end

      # Render document to HTML
      def render
        preambule if @options['preambule']
        _render(@document, indent = 2)
        postambule if @options['postambule']
      end

      private

      def _render(element, indent = 0)
        

      def preambule
        @options['preambule'] or <<~TEXT
        <!DOCTYPE HTML>
        <html>
          <head>
            #{@document['head']}
          </head>
          <body>
        TEXT
      end

      def postambule
        @options['postambule'] or <<~TEXT
          </body>
        </html>
        TEXT
      end    
    end
  end
end
